Changelog
=========

Unreleased_
-----------

0.0.3_ 2021-04-17
-----------------

Fixed
^^^^^

-   Remove the over large spacing in the sidebar lists

0.0.2_ 2021-03-21
-----------------

Changed
^^^^^^^

-   Version number to appease PyPI

0.0.1_ 2021-03-21
-----------------

-   Initial release

.. _Unreleased: https://github.com/kprussing/kpruss/compare/v0.0.3...HEAD
.. _0.0.3: https://github.com/kprussing/kpruss/compare/v0.0.2..v0.0.3
.. _0.0.2: https://github.com/kprussing/kpruss/compare/v0.0.1..v0.0.2
.. _0.0.1: https://github.com/kprussing/kpruss/releases/tag/v0.0.1
